@@ -1,6 +1,6 @@
 package Mojo::IOLoop::ReadWriteProcess;
 
-our $VERSION = '0.32';
+our $VERSION = '1.0.0';
 
 use Mojo::Base 'Mojo::EventEmitter';
 use Mojo::File 'path';
@@ -56,8 +56,8 @@ has session => sub { Mojo::IOLoop::ReadWriteProcess::Session->singleton };
 
 has _deparse => sub { B::Deparse->new }
   if DEBUG;
-has _deserialize => sub { \&Storable::thaw };
-has _serialize   => sub { \&Storable::freeze };
+has _deserialize             => sub { \&Storable::thaw };
+has _serialize               => sub { \&Storable::freeze };
 has _default_kill_signal     => POSIX::SIGTERM;
 has _default_blocking_signal => POSIX::SIGKILL;
 
@@ -76,7 +76,7 @@ sub to_ioloop {
   my $me = $$;
   $stream->on(
     close => sub {
-      return unless $$ == $me;
+      return                unless $$ == $me;
       $self->_collect->stop unless defined $self->_status;
     });
   return $stream;
@@ -297,13 +297,16 @@ sub _fork {
       $stdin = $input_pipe->reader() if $input_pipe;
       open STDERR, ">&", $stderr
         or !!$internal_err->write($!)
-        or $self->_diag($!);
+        or $self->_diag($!)
+        if $stderr;
       open STDOUT, ">&", $stdout
         or !!$internal_err->write($!)
-        or $self->_diag($!);
+        or $self->_diag($!)
+        if $stdout;
       open STDIN, ">&", $stdin
         or !!$internal_err->write($!)
-        or $self->_diag($!);
+        or $self->_diag($!)
+        if $stdin;
 
       $self->read_stream($stdin);
       $self->error_stream($stderr);
@@ -396,10 +399,12 @@ sub exit_status {
 sub restart {
   $_[0]->is_running ? $_[0]->stop->start : $_[0]->start;
 }
+
 sub is_running {
-    my ($self) = shift;
-    $self->session->consume_collected_info;
-    $self->process_id ? kill 0 => $self->process_id : 0;
+  my ($self) = shift;
+  $self->session->consume_collected_info;
+  return 0 unless my $pid = $self->process_id;
+  kill(0, ($self->kill_whole_group ? (-$pid, $pid) : ($pid)));
 }
 
 sub write_pidfile {
@@ -408,7 +413,7 @@ sub write_pidfile {
   return unless $self->pid;
   return unless $self->pidfile;
 
-  path($self->pidfile)->spurt($self->pid);
+  path($self->pidfile)->spew($self->pid);
   return $self;
 }
 
@@ -513,9 +518,8 @@ sub stop {
   my $self = shift;
 
   my $pid = $self->pid;
-  return $self unless defined $pid;
+  return $self               unless defined $pid;
   return $self->_shutdown(1) unless $self->is_running;
-  $self->_diag("Stopping $pid") if DEBUG;
 
   my $ret;
   my $attempt      = 1;
@@ -523,7 +527,9 @@ sub stop {
   my $sleep_time   = $self->sleeptime_during_kill;
   my $max_attempts = $self->max_kill_attempts;
   my $signal       = $self->_default_kill_signal;
-  $pid = -getpgrp($pid) if $self->kill_whole_group;
+  $pid = -$pid if $self->kill_whole_group;
+  $self->_diag("Stopping $pid") if DEBUG;
+
   until ((defined $ret && ($ret == $pid || $ret == -1))
       || ($attempt > $max_attempts && $timeout <= 0))
   {
@@ -663,6 +669,10 @@ Mojo::IOLoop::ReadWriteProcess - Execute external programs or internal code bloc
     $process->stop();
     my @errors = $process->error;
 
+    # To help when debugging Mojo::Collections
+    use Mojo::Util qw(dumper);
+    my $errors = dumper $process->error->to_array;
+
     # Get process return value
     $process = process( sub { return "256"; } )->start()->wait_stop;
     # We need to stop it to retrieve the exit status
@@ -902,7 +912,7 @@ Defaults to C<0>, If enabled data returned from forked process will be serialize
 
 =head2 kill_sleeptime
 
-Defaults to C<1>, it's the seconds to wait before attempting SIGKILL when blocking_stop is setted to 1.
+Defaults to C<1>, it's the seconds to wait before attempting SIGKILL when blocking_stop is set to 1.
 
 =head2 separate_err
 
@@ -998,7 +1008,7 @@ Inspect the codeblock return.
     my $p = process()->enable_subreaper;
 
 Mark the current process (not the child) as subreaper.
-This is used typically if you want to mark further childs as subreapers inside other forks.
+This is used typically if you want to mark further children as subreapers inside other forks.
 
     my $master_p = process(
       sub {
